@@ -11,6 +11,7 @@ setRefClass("status",
             fields = list(
               text="character",
               favorited="logical",
+              favoriteCount="numeric",
               replyToSN="character",
               created="POSIXct",
               truncated="logical",
@@ -20,9 +21,11 @@ setRefClass("status",
               statusSource="character",
               screenName="character",
               retweetCount="numeric",
+              isRetweet="logical",
               retweeted="logical",
               longitude="character",
-              latitude="character"
+              latitude="character",
+              urls="data.frame"
               ),
             methods=list(
               initialize = function(json, ...) {
@@ -79,21 +82,36 @@ setRefClass("status",
                   } else {
                     retweeted <<- TRUE
                   }
-                  if (!is.null(json[["coordinates"]]) && !(!is.null(json[["coordinates"]][["coordinates"]]))) {
-                    longitude <<- json[["coordinates"]][["coordinates"]]
-                    latitude <<- json[["coordinates"]][["coordinates"]]
+                  if (!is.null(json[["favorite_count"]])) {
+                    favoriteCount <<- as.numeric(json[["favorite_count"]])
                   }
-
+                  if (!is.null(json[["coordinates"]]) && (!is.null(json[["coordinates"]][["coordinates"]]))) {
+                    longitude <<- as.character(json[["coordinates"]][["coordinates"]][1])
+                    latitude <<- as.character(json[["coordinates"]][["coordinates"]][2])
+                  }
+                  
+                  ## If retweeted_status is provided (which contains the full original status), this is a retweet
+                  isRetweet <<- "retweeted_status" %in% names(json)
+                  
+                  urls <<- build_urls_data_frame(json)
                 }
                 callSuper(...)
+              },
+              getRetweets = function(n=20, ...) {
+                return(retweets(self$getId(), n, ...))
+              },
+              toDataFrame = function(row.names=NULL, optional=FALSE, stringsAsFactors=FALSE) {
+                callSuper(row.names=row.names, optional=optional, stringsAsFactors=stringsAsFactors, 
+                          fieldsToRemove="urls")
               }
               )
             )
 
-statusFactory <- getRefClass("status")
+
+statusFactory = getRefClass("status")
 statusFactory$accessors(names(statusFactory$fields()))
 
-buildStatus <- function(json) {
+buildStatus = function(json) {
   return(statusFactory$new(json))
 }
 
@@ -101,7 +119,6 @@ setMethod("show", signature="status", function(object) {
     print(paste(screenName(object), object$text, sep=": "))
 })
 
-
 updateStatus <- function(text, lat=NULL, long=NULL, placeID=NULL,
                          displayCoords=NULL, inReplyTo=NULL, ...) {
   if (!hasOAuth())
@@ -110,38 +127,41 @@ updateStatus <- function(text, lat=NULL, long=NULL, placeID=NULL,
   if (nchar(text) > 140)
     stop("Status can not be more than 140 characters")
 
-  params <- buildCommonArgs(lat=lat, long=long, place_id=placeID,
+  params = buildCommonArgs(lat=lat, long=long, place_id=placeID,
                             display_coordinates=displayCoords,
                             in_reply_to_status_id=inReplyTo)
   params[['status']] <- text
-  json <- twInterfaceObj$doAPICall('statuses/update',
-                                   params=params, method='POST', ...)
+  json = twInterfaceObj$doAPICall('statuses/update',
+                                 params=params, method='POST', ...)
   return(buildStatus(json))
 }
             
-tweet <- function(text, ...) {
-    updateStatus(text, ...)
+tweet = function(text, ...) {
+    return(updateStatus(text, ...))
 }
 
-deleteStatus <- function(status, ...) {
-  if (!hasOAuth())
+deleteStatus = function(status, ...) {
+  if (!hasOAuth()) {
     stop("deleteStatus requires OAuth authentication")
-  if (!inherits(status, 'status'))
+  }
+  if (!inherits(status, 'status')) {
     stop("status argument must be of class status")
-  json <- twInterfaceObj$doAPICall(paste('statuses/destroy',
-                                         status$getId(), sep='/'),
-                                   method='POST', ...)
+  }
+  
+  json = twInterfaceObj$doAPICall(paste('statuses/destroy',
+                                       status$getId(), sep='/'),
+                                       method='POST', ...)
   if (is.null(json$errors)) {
-    TRUE
+    return(TRUE)
   } else {
     for (error in json$errors) {
       cat(error$message, error$code, fill = TRUE)
     }
-    FALSE
+    return(FALSE)
   }
 }
 
-showStatus <- function(id, ...) {
+showStatus = function(id, ...) {
   if (!is.character(id)) {
     warning("Using numeric id value can lead to unexpected results for very large ids")
   }
@@ -152,24 +172,53 @@ showStatus <- function(id, ...) {
   buildStatus(twInterfaceObj$doAPICall(paste('statuses', 'show', id, sep='/'), ...))
 }
 
-userTimeline <- function(user, n=20, maxID=NULL, sinceID=NULL, includeRts=FALSE, ...) {
+retweets = function(id, n=20, ...) {
+  if (!is.character(id)) {
+    warning("Using numeric id value can lead to unexpected results for very large ids")
+  }
+  if (is.na(as.numeric(id))) {
+    stop("Malformed id, while it must be a string all ids must be representable as an integer")
+  }
+
+  if (n> 100) {
+    stop("n must be less than 100, set to ", n)
+  }
+  
+  cmd = "statuses/retweets"
+  params = list(id=id, count=n)
+  return(sapply(doAPICall(cmd, params=params), buildStatus))  
+}
+
+favorites = function(user, n=20, max_id=NULL, since_id=NULL, ...) {
+  uParams = parseUsers(user)
+  cmd = "favorites/list"
+  params = buildCommonArgs(max_id=max_id, since_id=since_id)
+  params[["user_id"]] = uParams[["user_id"]]
+  params[["screen_name"]] = uParams[["screen_name"]]
+  return(statusBase(cmd, params, n, 200, ...))
+}
+
+userTimeline = function(user, n=20, maxID=NULL, sinceID=NULL, includeRts=FALSE, ...) {
   uParams <- parseUsers(user)
   cmd <- 'statuses/user_timeline'
   params <- buildCommonArgs(max_id=maxID, since_id=sinceID)
   params[['user_id']] <- uParams[['user_id']]
   params[['screen_name']] <- uParams[['screen_name']]
   params[["include_rts"]] <- ifelse(includeRts == TRUE, "true", "false")
-  statusBase(cmd, params, n, 3200, ...)
+  return(statusBase(cmd, params, n, 3200, ...))
 }
 
-homeTimeline <- function(n=25, maxID=NULL, sinceID=NULL, ...) 
-  authStatusBase(n, 'home_timeline', maxID=maxID, sinceID=sinceID, ...)
+homeTimeline <- function(n=25, maxID=NULL, sinceID=NULL, ...) {
+  return(authStatusBase(n, 'home_timeline', maxID=maxID, sinceID=sinceID, ...))
+}
 
-mentions <- function(n=25, maxID=NULL, sinceID=NULL, ...)
-  authStatusBase(n, 'mentions_timeline', maxID=maxID, sinceID=sinceID, ...)
+mentions <- function(n=25, maxID=NULL, sinceID=NULL, ...) {
+  return(authStatusBase(n, 'mentions_timeline', maxID=maxID, sinceID=sinceID, ...))
+}
 
-retweetsOfMe <- function(n=25, maxID=NULL, sinceID=NULL, ...)
-  authStatusBase(n, 'retweets_of_me', maxID=maxID, sinceID=sinceID, ...)
+retweetsOfMe <- function(n=25, maxID=NULL, sinceID=NULL, ...) {
+  return(authStatusBase(n, 'retweets_of_me', maxID=maxID, sinceID=sinceID, ...))
+}
 
 authStatusBase <- function(n, type, maxID=NULL, sinceID=NULL, ...) {
   if (!hasOAuth()) {
@@ -179,7 +228,7 @@ authStatusBase <- function(n, type, maxID=NULL, sinceID=NULL, ...) {
   params <- buildCommonArgs(max_id=maxID, since_id=sinceID)
   cmd <- paste('statuses', type, sep='/')
   cmd <- paste('statuses', type, sep='/')
-  statusBase(cmd, params, n, 800, ...)
+  return(statusBase(cmd, params, n, 800, ...))
 }
 
 statusBase <- function(cmd, params, n, maxN, ...) {
@@ -188,5 +237,24 @@ statusBase <- function(cmd, params, n, maxN, ...) {
     warning(cmd, " has a cap of ", maxN, " statuses, clipping")
     n <- maxN
   }
-  sapply(doPagedAPICall(cmd, n, params, ...), buildStatus)
+  return(sapply(doPagedAPICall(cmd, n, params, ...), buildStatus))
+}
+
+build_urls_data_frame = function(json) {
+  ## takes a status JSON and will either return a data.frame of the URLs entity or an
+  ## empty data.frame if there were none provided
+  split_indices = function(urls_block) {
+    urls_block$start_index = urls_block$indices[1]
+    urls_block$stop_index = urls_block$indices[2]
+    urls_block$indices = NULL
+    urls_block
+  }
+  
+  if (length(json$entities$urls) > 0) {
+    urls = json$entities$urls
+    massaged_urls = lapply(urls, split_indices)
+    return(do.call("rbind", lapply(massaged_urls, as.data.frame, stringsAsFactors=FALSE)))
+  } else {
+    data.frame(url=character(), expanded_url=character(), dispaly_url=character(), indices=numeric(), stringsAsFactors=FALSE)
+  }
 }
