@@ -1,3 +1,9 @@
+
+decode_short_url <- function(url, ...) {
+  request_url = paste("http://api.longurl.org/v2/expand?url=", url, "&format=json", sep="")
+  return(fromJSON(getURL(request_url, useragent="twitteR", ...))[["long-url"]])
+}
+
 getAPIStr <- function(cmd, version=1.1) {
   if (hasOAuth()) {
     scheme <- "https"
@@ -25,12 +31,17 @@ buildCommonArgs <- function(lang=NULL, since=NULL, until=NULL, locale=NULL,
 parseUsers <- function(users) {
   ## many functions have 'user' input which can be one of class 'user', a UID or a screen name,
   ## try to do something rational here
-  users <- sapply(users, function(x) {
-    if (inherits(x, 'user'))
-      x$getScreenName()
-    else
-      x
-  })
+  if ((length(users) == 1) && (inherits(users, "user"))) {
+    users = users$getScreenName()
+  } else {
+    users <- sapply(users, function(x) {
+      if (inherits(x, 'user'))
+        x$getScreenName()
+      else
+        x
+    })
+  }
+  
   numUsers <- suppressWarnings(as.numeric(users))
   uids <- numUsers[!is.na(numUsers)]
   screen.names <- setdiff(users, uids)
@@ -58,7 +69,7 @@ twListToDF <- function(twList) {
   if (length(classes) != 1) {
     stop("Not all elements of twList are of the same class")
   }
-  if (! classes %in% c('status', 'user', 'directMessage', 'rateLimitInfo')) {
+  if (! classes %in% c('status', 'user', 'directMessage')) {
     stop("Elements of twList are not of an appropriate class")
   }
   do.call('rbind', lapply(twList, as.data.frame))
